# coding: utf-8

"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr, validator
from cryptoapis.models.address_coins_transaction_confirmed_each_confirmation_data_item_mined_in_block import AddressCoinsTransactionConfirmedEachConfirmationDataItemMinedInBlock

class AddressCoinsTransactionConfirmedEachConfirmationDataItem(BaseModel):
    """
    Defines an `item` as one result.
    """
    blockchain: StrictStr = Field(..., description="Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.")
    network: StrictStr = Field(..., description="Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"goerli\", \"nile\" are test networks.")
    address: StrictStr = Field(..., description="Defines the specific address to which the transaction has been sent.")
    mined_in_block: AddressCoinsTransactionConfirmedEachConfirmationDataItemMinedInBlock = Field(..., alias="minedInBlock")
    transaction_id: StrictStr = Field(..., alias="transactionId", description="Defines the unique ID of the specific transaction, i.e. its identification number.")
    current_confirmations: StrictInt = Field(..., alias="currentConfirmations", description="Defines the number of currently received confirmations for the transaction.")
    target_confirmations: StrictInt = Field(..., alias="targetConfirmations", description="Defines the number of confirmation transactions requested as callbacks, i.e. the system can notify till the n-th confirmation.")
    amount: StrictStr = Field(..., description="Defines the amount of coins sent with the confirmed transaction.")
    unit: StrictStr = Field(..., description="Defines the unit of the transaction, e.g. BTC.")
    direction: StrictStr = Field(..., description="Defines whether the transaction is \"incoming\" or \"outgoing\".")
    __properties = ["blockchain", "network", "address", "minedInBlock", "transactionId", "currentConfirmations", "targetConfirmations", "amount", "unit", "direction"]

    @validator('direction')
    def direction_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('incoming', 'outgoing'):
            raise ValueError("must be one of enum values ('incoming', 'outgoing')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AddressCoinsTransactionConfirmedEachConfirmationDataItem:
        """Create an instance of AddressCoinsTransactionConfirmedEachConfirmationDataItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of mined_in_block
        if self.mined_in_block:
            _dict['minedInBlock'] = self.mined_in_block.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AddressCoinsTransactionConfirmedEachConfirmationDataItem:
        """Create an instance of AddressCoinsTransactionConfirmedEachConfirmationDataItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AddressCoinsTransactionConfirmedEachConfirmationDataItem.parse_obj(obj)

        _obj = AddressCoinsTransactionConfirmedEachConfirmationDataItem.parse_obj({
            "blockchain": obj.get("blockchain"),
            "network": obj.get("network"),
            "address": obj.get("address"),
            "mined_in_block": AddressCoinsTransactionConfirmedEachConfirmationDataItemMinedInBlock.from_dict(obj.get("minedInBlock")) if obj.get("minedInBlock") is not None else None,
            "transaction_id": obj.get("transactionId"),
            "current_confirmations": obj.get("currentConfirmations"),
            "target_confirmations": obj.get("targetConfirmations"),
            "amount": obj.get("amount"),
            "unit": obj.get("unit"),
            "direction": obj.get("direction")
        })
        return _obj

