# coding: utf-8

"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr, validator
from cryptoapis.models.address_internal_transaction_confirmed_data_item_mined_in_block import AddressInternalTransactionConfirmedDataItemMinedInBlock

class AddressInternalTransactionConfirmedDataItem(BaseModel):
    """
    Defines an `item` as one result.
    """
    blockchain: StrictStr = Field(..., description="Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.")
    network: StrictStr = Field(..., description="Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.")
    address: StrictStr = Field(..., description="Defines the specific address of the internal transaction.")
    mined_in_block: AddressInternalTransactionConfirmedDataItemMinedInBlock = Field(..., alias="minedInBlock")
    parent_transaction_id: StrictStr = Field(..., alias="parentTransactionId", description="Defines the Parent Transaction's unique ID.")
    operation_id: StrictStr = Field(..., alias="operationId", description="Defines the specific operation's unique ID.")
    amount: StrictStr = Field(..., description="Defines the amount of coins sent with the confirmed transaction.")
    unit: StrictStr = Field(..., description="Defines the unit of the transaction, e.g. Gwei.")
    direction: StrictStr = Field(..., description="Defines whether the transaction is \"incoming\" or \"outgoing\".")
    __properties = ["blockchain", "network", "address", "minedInBlock", "parentTransactionId", "operationId", "amount", "unit", "direction"]

    @validator('direction')
    def direction_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('incoming', 'outgoing'):
            raise ValueError("must be one of enum values ('incoming', 'outgoing')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AddressInternalTransactionConfirmedDataItem:
        """Create an instance of AddressInternalTransactionConfirmedDataItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of mined_in_block
        if self.mined_in_block:
            _dict['minedInBlock'] = self.mined_in_block.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AddressInternalTransactionConfirmedDataItem:
        """Create an instance of AddressInternalTransactionConfirmedDataItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AddressInternalTransactionConfirmedDataItem.parse_obj(obj)

        _obj = AddressInternalTransactionConfirmedDataItem.parse_obj({
            "blockchain": obj.get("blockchain"),
            "network": obj.get("network"),
            "address": obj.get("address"),
            "mined_in_block": AddressInternalTransactionConfirmedDataItemMinedInBlock.from_dict(obj.get("minedInBlock")) if obj.get("minedInBlock") is not None else None,
            "parent_transaction_id": obj.get("parentTransactionId"),
            "operation_id": obj.get("operationId"),
            "amount": obj.get("amount"),
            "unit": obj.get("unit"),
            "direction": obj.get("direction")
        })
        return _obj

