# coding: utf-8

"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from cryptoapis.models.get_block_details_by_block_hash_from_callback_ribs import GetBlockDetailsByBlockHashFromCallbackRIBS

class GetBlockDetailsByBlockHashFromCallbackRI(BaseModel):
    """
    GetBlockDetailsByBlockHashFromCallbackRI
    """
    hash: StrictStr = Field(..., description="Represents the hash of the block, which is its unique identifier. It represents a cryptographic digital fingerprint made by hashing the block header twice through the SHA256 algorithm.")
    height: StrictInt = Field(..., description="Represents the number of blocks in the blockchain preceding this specific block. Block numbers have no gaps. A blockchain usually starts with block 0 called the \"Genesis block\".")
    previous_block_hash: StrictStr = Field(..., alias="previousBlockHash", description="Represents the hash of the previous block, also known as the parent block.")
    timestamp: StrictInt = Field(..., description="Defines the exact date/time when this block was mined in Unix Timestamp.")
    transactions_count: StrictInt = Field(..., alias="transactionsCount", description="Represents the total number of all transactions as part of this block.")
    difficulty: StrictStr = Field(..., description="Represents a mathematical value of how hard it is to find a valid hash for this block.")
    extra_data: StrictStr = Field(..., alias="extraData", description="Represents any data that can be included by the miner in the block.")
    gas_limit: StrictStr = Field(..., alias="gasLimit", description="Represents the amount of gas used by this specific transaction alone.")
    gas_used: StrictStr = Field(..., alias="gasUsed", description="Represents the exact unit of gas that was used for the transaction.")
    mined_in_seconds: StrictInt = Field(..., alias="minedInSeconds", description="Specifies the amount of time required for the block to be mined in seconds.")
    nonce: StrictStr = Field(..., description="Represents the sequential running number for an address, starting from 0 for the first transaction. E.g., if the nonce of a transaction is 10, it would be the 11th transaction sent from the sender's address.")
    sha3_uncles: StrictStr = Field(..., alias="sha3Uncles", description="Defines the combined hash of all uncles for a given parent.")
    size: StrictInt = Field(..., description="Represents the total size of the block in Bytes.")
    total_difficulty: StrictStr = Field(..., alias="totalDifficulty", description="Defines the total difficulty of the chain until this block, i.e. how difficult it is for a specific miner to mine a new block.")
    uncles: conlist(StrictStr) = Field(...)
    blockchain_specific: GetBlockDetailsByBlockHashFromCallbackRIBS = Field(..., alias="blockchainSpecific")
    __properties = ["hash", "height", "previousBlockHash", "timestamp", "transactionsCount", "difficulty", "extraData", "gasLimit", "gasUsed", "minedInSeconds", "nonce", "sha3Uncles", "size", "totalDifficulty", "uncles", "blockchainSpecific"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetBlockDetailsByBlockHashFromCallbackRI:
        """Create an instance of GetBlockDetailsByBlockHashFromCallbackRI from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of blockchain_specific
        if self.blockchain_specific:
            _dict['blockchainSpecific'] = self.blockchain_specific.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetBlockDetailsByBlockHashFromCallbackRI:
        """Create an instance of GetBlockDetailsByBlockHashFromCallbackRI from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetBlockDetailsByBlockHashFromCallbackRI.parse_obj(obj)

        _obj = GetBlockDetailsByBlockHashFromCallbackRI.parse_obj({
            "hash": obj.get("hash"),
            "height": obj.get("height"),
            "previous_block_hash": obj.get("previousBlockHash"),
            "timestamp": obj.get("timestamp"),
            "transactions_count": obj.get("transactionsCount"),
            "difficulty": obj.get("difficulty"),
            "extra_data": obj.get("extraData"),
            "gas_limit": obj.get("gasLimit"),
            "gas_used": obj.get("gasUsed"),
            "mined_in_seconds": obj.get("minedInSeconds"),
            "nonce": obj.get("nonce"),
            "sha3_uncles": obj.get("sha3Uncles"),
            "size": obj.get("size"),
            "total_difficulty": obj.get("totalDifficulty"),
            "uncles": obj.get("uncles"),
            "blockchain_specific": GetBlockDetailsByBlockHashFromCallbackRIBS.from_dict(obj.get("blockchainSpecific")) if obj.get("blockchainSpecific") is not None else None
        })
        return _obj

